@@ -141,17 +141,16 @@ module Puppet::Environments
   class StaticDirectory < Static
     # Accepts a single environment in the given directory having the given name (not required to be reflected as the name
     # of the directory)
-    # 
     def initialize(env_name, env_dir, environment)
       super(environment)
       @env_dir = env_dir
-      @env_name = env_name
+      @env_name = env_name.intern
     end
 
     # @!macro loader_get_conf
     def get_conf(name)
-      return nil unless name == @env_name
-      Puppet::Settings::EnvironmentConf.load_from(@env_dir, '')
+      return nil unless name.intern == @env_name
+      Puppet::Settings::EnvironmentConf.load_from(@env_dir, [])
     end
   end
 
@@ -268,7 +267,8 @@ module Puppet::Environments
     # @!macro loader_get
     def get(name)
       @loaders.each do |loader|
-        if env = loader.get(name)
+        env = loader.get(name)
+        if env 
           return env
         end
       end
@@ -278,7 +278,8 @@ module Puppet::Environments
     # @!macro loader_get_conf
     def get_conf(name)
       @loaders.each do |loader|
-        if conf = loader.get_conf(name)
+        conf = loader.get_conf(name)
+        if conf
           return conf
         end
       end
@@ -349,7 +350,8 @@ module Puppet::Environments
       # This strategy favors smaller memory footprint over environment
       # retrieval time.
       clear_all_expired
-      if result = @cache[name]
+      result = @cache[name]
+      if result
         # found in cache
         return result.value
       elsif (result = @loader.get(name))
