@@ -32,9 +32,9 @@ Puppet::Type.newtype(:file) do
     **Autorequires:** If Puppet is managing the user or group that owns a
     file, the file resource will autorequire them. If Puppet is managing any
     parent directories of a file, the file resource autorequires them.
-    
-    Warning: Enabling `recurse` on directories containing large numbers of 
-    files slows agent runs. To manage file attributes for many files, 
+
+    Warning: Enabling `recurse` on directories containing large numbers of
+    files slows agent runs. To manage file attributes for many files,
     consider using alternative methods such as the `chmod_r`, `chown_r`,
      or `recursive_file_permissions` modules from the Forge."
 
@@ -298,6 +298,30 @@ Puppet::Type.newtype(:file) do
     defaultto :true
   end
 
+  newparam(:staging_location) do
+    desc "When rendering a file first render it to this location. The default
+         location is the same path as the desired location with a unique filename.
+         This parameter is useful in conjuction with validate_cmd to test a
+         file before moving the file to it's final location.
+         WARNING: File replacement is only guaranteed to be atomic if the staging
+         location is on the same filesystem as the final location."
+
+    validate do |value|
+      unless Puppet::Util.absolute_path?(value)
+        fail Puppet::Error, "File paths must be fully qualified, not '#{value}'"
+      end
+    end
+
+    munge do |value|
+      if value.start_with?('//') and ::File.basename(value) == "/"
+        # This is a UNC path pointing to a share, so don't add a trailing slash
+        ::File.expand_path(value)
+      else
+        ::File.join(::File.split(::File.expand_path(value)))
+      end
+    end
+  end
+
   newparam(:validate_cmd) do
     desc "A command for validating the file's syntax before replacing it. If
       Puppet would need to rewrite a file due to new `source` or `content`, it
@@ -337,7 +361,8 @@ Puppet::Type.newtype(:file) do
     if !path.root?
       # Start at our parent, to avoid autorequiring ourself
       parents = path.parent.enum_for(:ascend)
-      if found = parents.find { |p| catalog.resource(:file, p.to_s) }
+      found = parents.find { |p| catalog.resource(:file, p.to_s) }
+      if found
         req << found.to_s
       end
     end
@@ -351,7 +376,8 @@ Puppet::Type.newtype(:file) do
     autorequire(type) do
       if @parameters.include?(property)
         # The user/group property automatically converts to IDs
-        next unless should = @parameters[property].shouldorig
+        should = @parameters[property].shouldorig
+        next unless should
         val = should[0]
         if val.is_a?(Integer) or val =~ /^\d+$/
           nil
@@ -434,7 +460,8 @@ Puppet::Type.newtype(:file) do
       fail _("Can not find filebucket for backups without a catalog")
     end
 
-    unless catalog and filebucket = catalog.resource(:filebucket, backup) or backup == "puppet"
+    filebucket = catalog.resource(:filebucket, backup) if catalog
+    if !catalog || (!filebucket && backup != 'puppet')
       fail _("Could not find filebucket %{backup} specified in backup") % { backup: backup }
     end
 
@@ -545,7 +572,8 @@ Puppet::Type.newtype(:file) do
   def pathbuilder
     # We specifically need to call the method here, so it looks
     # up our parent in the catalog graph.
-    if parent = parent()
+    parent = parent()
+    if parent
       # We only need to behave specially when our parent is also
       # a file
       if parent.is_a?(self.class)
@@ -668,14 +696,16 @@ Puppet::Type.newtype(:file) do
     total = self[:source].collect do |source|
       # For each inlined file resource, the catalog contains a hash mapping
       # source path to lists of metadata returned by a server-side search.
-      if recursive_metadata = catalog.recursive_metadata[title]
+      recursive_metadata = catalog.recursive_metadata[title]
+      if recursive_metadata
         result = recursive_metadata[source]
       else
         result = perform_recursion(source)
       end
 
       next unless result
-      return [] if top = result.find { |r| r.relative_path == "." } and top.ftype != "directory"
+      top = result.find { |r| r.relative_path == "." }
+      return [] if top && top.ftype != "directory"
       result.each do |data|
         if data.relative_path == '.'
           data.source = source
@@ -799,12 +829,12 @@ Puppet::Type.newtype(:file) do
     return true if self[:ensure] == :file
 
     # I.e., it's set to something like "directory"
-    return false if e = self[:ensure] and e != :present
+    return false if self[:ensure] && self[:ensure] != :present
 
     # The user doesn't really care, apparently
     if self[:ensure] == :present
-      return true unless s = stat
-      return(s.ftype == "file" ? true : false)
+      return true unless stat
+      return(stat.ftype == "file" ? true : false)
     end
 
     # If we've gotten here, then :ensure isn't set
@@ -862,7 +892,16 @@ Puppet::Type.newtype(:file) do
     mode_int = mode ? symbolic_mode_to_int(mode, Puppet::Util::DEFAULT_POSIX_MODE) : nil
 
     if write_temporary_file?
-      Puppet::Util.replace_file(self[:path], mode_int) do |file|
+      if self[:validate_cmd]
+        validate_callback = proc { |path|
+          output = Puppet::Util::Execution.execute(self[:validate_cmd].gsub(self[:validate_replacement], path), :failonfail => true, :combine => true)
+          output.split(/\n/).each { |line|
+            self.debug(line)
+          }
+        }
+      end
+
+      Puppet::Util.replace_file(self[:path], mode_int, staging_location: self[:staging_location], validate_callback: validate_callback) do |file|
         file.binmode
         devfail 'a property should have been provided if write_temporary_file? returned true' if property.nil?
         content_checksum = property.write(file)
@@ -880,12 +919,6 @@ Puppet::Type.newtype(:file) do
         end
 
         fail_if_checksum_is_wrong(file.path, content_checksum) if validate_checksum?
-        if self[:validate_cmd]
-          output = Puppet::Util::Execution.execute(self[:validate_cmd].gsub(self[:validate_replacement], file.path), :failonfail => true, :combine => true)
-          output.split(/\n/).each { |line|
-            self.debug(line)
-          }
-        end
       end
     else
       umask = mode ? 000 : 022
